# SSAW: Python wrapper for the Survey Solutions REST API

[![Build Status](https://travis-ci.org/vavalomi/ssaw.svg?branch=master)](https://travis-ci.org/vavalomi/ssaw)

Read more about Survey Solutions at http://worldbank.org/capi

Details on API at <https://demo.mysurvey.solutions/apidocs/index>